Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Private Certificate Authority.

Actions, resources, and condition keys for AWS Private Certificate Authority - Service Authorization Reference

# Actions, resources, and condition keys for AWS Private Certificate Authority

AWS Private Certificate Authority (service prefix: `acm-pca` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by AWS Private Certificate Authority
- Resource types defined by AWS Private Certificate Authority
- Condition keys for AWS Private Certificate Authority

## Actions defined by AWS Private Certificate Authority

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CreateCertificateAuthority | Grants permission to create an AWS Private CA and its associated private key and configuration | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateCertificateAuthorityAuditReport | Grants permission to create an audit report for an AWS Private CA | Write | certificate-authority* |  |
CreatePermission | Grants permission to create a permission for an AWS Private CA | Permissions management | certificate-authority* |  |
DeleteCertificateAuthority | Grants permission to delete an AWS Private CA and its associated private key and configuration | Write | certificate-authority* |  |
DeletePermission | Grants permission to delete a permission for an AWS Private CA | Permissions management | certificate-authority* |  |
DeletePolicy | Grants permission to delete the policy for an AWS Private CA | Permissions management | certificate-authority* |  |
DescribeCertificateAuthority | Grants permission to return a list of the configuration and status fields contained in the specified AWS Private CA | Read | certificate-authority* |  |
DescribeCertificateAuthorityAuditReport | Grants permission to return the status and information about an AWS Private CA audit report | Read | certificate-authority* |  |
GetCertificate | Grants permission to retrieve an AWS Private CA certificate and certificate chain for the certificate authority specified by an ARN | Read | certificate-authority* |  |
GetCertificateAuthorityCertificate | Grants permission to retrieve an AWS Private CA certificate and certificate chain for the certificate authority specified by an ARN | Read | certificate-authority* |  |
GetCertificateAuthorityCsr | Grants permission to retrieve an AWS Private CA certificate signing request (CSR) for the certificate-authority specified by an ARN | Read | certificate-authority* |  |
GetPolicy | Grants permission to retrieve the policy on an AWS Private CA | Read | certificate-authority* |  |
ImportCertificateAuthorityCertificate | Grants permission to import an SSL/TLS certificate into AWS Private CA for use as the CA certificate of an AWS Private CA | Write | certificate-authority* |  |
IssueCertificate | Grants permission to issue an AWS Private CA certificate | Write | certificate-authority* |  |
| acm-pca:TemplateArn |
ListCertificateAuthorities | Grants permission to retrieve a list of the AWS Private CA certificate authority ARNs, and a summary of the status of each CA in the calling account | List |  |  |
ListPermissions | Grants permission to list the permissions that have been applied to the AWS Private CA certificate authority | Read | certificate-authority* |  |
ListTags | Grants permission to list the tags that have been applied to the AWS Private CA certificate authority | Read | certificate-authority* |  |
PutPolicy | Grants permission to put a policy on an AWS Private CA | Permissions management | certificate-authority* |  |
RestoreCertificateAuthority | Grants permission to restore an AWS Private CA from the deleted state to the state it was in when deleted | Write | certificate-authority* |  |
RevokeCertificate | Grants permission to revoke a certificate issued by an AWS Private CA | Write | certificate-authority* |  |
TagCertificateAuthority | Grants permission to add one or more tags to an AWS Private CA | Tagging | certificate-authority* |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagCertificateAuthority | Grants permission to remove one or more tags from an AWS Private CA | Tagging | certificate-authority* |  |
| aws:TagKeys |
UpdateCertificateAuthority | Grants permission to update the configuration of an AWS Private CA | Write | certificate-authority* |  |

## Resource types defined by AWS Private Certificate Authority

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
certificate-authority | `arn:$ { Partition}:acm-pca:$ { Region}:$ { Account}:certificate-authority/$ { CertificateAuthorityId}` | aws:ResourceTag/${TagKey}

## Condition keys for AWS Private Certificate Authority

AWS Private Certificate Authority defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
acm-pca:TemplateArn | Filters issue certificate requests based on the presence of TemplateArn in the request | String
aws:RequestTag/${TagKey} | Filters create requests based on the allowed set of values for each of the tags | String
aws:ResourceTag/${TagKey} | Filters actions based on tag-value associated with the resource | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.